@@ -30,7 +30,8 @@ if __name__ == '__main__':
 line_attributes = ["linestyle","linewidth","color","marker","markersize","markerfacecolor","markeredgewidth","markeredgecolor"]
 image_undo_list = []
 
-
+# Pylab's ginput function.
+ginput = _pylab.ginput
 
 
 def add_text(text, x=0.01, y=0.01, axes="gca", draw=True, **kwargs):
